<?php

namespace CRM\Service;

use CRM\Factory\CrmConcorrenteFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CrmConcorrenteService
{

    protected $CrmConcorrenteFactory;
    protected $environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $environment, NewCode $newCode, EntityManager $entityManager, CrmConcorrenteFactory $CrmConcorrenteFactory)
    {
        $this->CrmConcorrenteFactory = $CrmConcorrenteFactory;
        $this->environment           = $environment;
        $this->newCode               = $newCode;
        $this->connection            = $entityManager->getConnection();
    }

    public function getCompetitionService()
    {
        return $this->CrmConcorrenteFactory->getCompetitionFactory();
    }

    public function saveNewCompetitionService($rows)
    {
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $this->connection->beginTransaction();
        try {

            $nrconcorrente = $this->newCode->getCodeByTableName("NRCONCORRENTE", $nrorg, 1, 5, false);
            $params = array(
                "NRCONCORRENTE"    => $nrconcorrente,
                "NRINSCRICAOCONC"  => $rows['NRINSCRICAOCONC'],
                "CDTIPOINSCRICAO"  => $rows['CDTIPOINSCRICAO'],
                "NMRAZSOCCONC"     => $rows['NMRAZSOCCONC'],
                "NMFANTCONN"       => $rows['NMFANTCONN'],
                "NRCEPCONC"        => null,
                "CDPAIS"           => $rows['CDPAIS'],
                "SGESTADO"         => $rows['SGESTADO'],
                "CDMUNICIPIO"      => $rows['CDMUNICIPIO'],
                "CDBAIRRO"         => $rows['CDBAIRRO'],
                "DSENDERECOCONC"   => $rows['DSENDERECOCONC'],
                "NRENDERECOCONC"   => $rows['NRENDERECOCONC'],
                "DSCOMPLEENDECONC" => $rows['DSCOMPLEENDECONC'],
                "NRTELCONC"        => $rows['NRTELCONC'],
                "DSEMAILCONC"      => $rows['DSEMAILCONC'],
                "DSHOMEPAGECONC"   => $rows['DSHOMEPAGECONC'],
                "DSOBSERVCONC"     => $rows['DSOBSERVCONC'],
                "NRORG"            => $nrorg,
                "NRORGINCLUSAO"    => $nrorg,
                "NRORGULTATU"      => $nrorg,
                "CDOPERINCLUSAO"    => $cdoperador,
                "CDOPERULTATU"      => $cdoperador,
                "IDATIVO"          => $rows['IDATIVO'],
                "NMPAIS"           => NULL,
                "NMESTADO"         => NULL,
                "NMMUNICIPIO"      => NULL,
                "NMBAIRRO"         => NULL
            );
            print_r($params);
            $this->CrmConcorrenteFactory->insertNewCompetitionFactory($params);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function updateCompetitionService($rows)
    {

        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();
        $this->connection->beginTransaction();
        try {

            $params = array(
                "NRCONCORRENTE"     => $rows['NRCONCORRENTE'],
                "NRINSCRICAOCONC"   => $rows['NRINSCRICAOCONC'],
                "CDTIPOINSCRICAO"   => $rows['CDTIPOINSCRICAO'],
                "NMRAZSOCCONC"      => $rows['NMRAZSOCCONC'],
                "NMFANTCONN"        => $rows['NMFANTCONN'],
                "NRCEPCONC"         => null,
                "CDPAIS"            => $rows['CDPAIS'],
                "SGESTADO"          => $rows['SGESTADO'],
                "CDMUNICIPIO"       => $rows['CDMUNICIPIO'],
                "CDBAIRRO"          => $rows['CDBAIRRO'],
                "DSENDERECOCONC"    => $rows['DSENDERECOCONC'],
                "NRENDERECOCONC"    => $rows['NRENDERECOCONC'],
                "DSCOMPLEENDECONC"  => $rows['DSCOMPLEENDECONC'],
                "NRTELCONC"         => $rows['NRTELCONC'],
                "DSEMAILCONC"       => $rows['DSEMAILCONC'],
                "DSHOMEPAGECONC"    => $rows['DSHOMEPAGECONC'],
                "DSOBSERVCONC"      => $rows['DSOBSERVCONC'],
                "NRORG"             => $nrorg,
                "NRORGINCLUSAO"     => $nrorg,
                "NRORGULTATU"       => $nrorg,
                "CDOPERINCLUSAO"    => $cdoperador,
                "CDOPERULTATU"      => $cdoperador,
                "IDATIVO"           => $rows['IDATIVO'],
                "NMPAIS"            => NULL,
                "NMESTADO"          => NULL,
                "NMMUNICIPIO"       => NULL,
                "NMBAIRRO"          => NULL
            );

            $this->CrmConcorrenteFactory->updateCompetitionFactory($params);

            $this->connection->commit();
        } catch (\Exception $e) {

            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteCompetitionService($row)
    {
        $this->connection->beginTransaction();
        try {
                $relationships = $this->findRelationship($row);

                if ($relationships[0]["NRCONCORRENTE"] == 0) {
                    $params = implode(',', $row["NRCONCORRENTE"]);                    
                    $this->CrmConcorrenteFactory->deleteCompetitionFactory($params);
                } else {

                    throw new \Exception("Este Concorrente Não Pode Ser Excluido, Pois Já Está Sendo Utilizada!");
                }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function findRelationship($row)
    {
        $params = array(
            "NRCONCORRENTE" => implode(',', $row["NRCONCORRENTE"]),
        );
        return $this->CrmConcorrenteFactory->findRelationshipFactory($params);
    }
}
