import {
  IEventParam,
  Metadata,
  Http,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import {
  Button,
  LoadingService,
  DialogService,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';

export class Ger91600TipoDeAtividadeController {
  public addNewRow({ component }: IEventParam<TekGrid>) {
    const newId = 0;
    component.addNewRow({ NRSEQTPATIVCLI: newId, IDATIVO: 'S' }, 'start');
  }

  public saveNewActivity({ component, event }: IEventParam<TekGrid>) {
    event!.preventDefault();
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/saveNewActivity', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public reloadGrid(grid: any) {
    const filterButton = Metadata.getInstance<Button>(`${grid}_refreshButton`);
    filterButton.click({} as Event, {} as HTMLElement);
  }

  public openFilter({ component }: any) {
    const filterButton = Metadata.getInstance<Button>(
      `${component.name}_filterButton`,
    );
    filterButton.click({} as Event, {} as HTMLElement);
  }

  /* eslint-disable */
  public canEditRow({ row }: any) {
    return row['__added_row'] === true;
  }
  /* eslint-enable */

  public dialogdeleteActivity({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'Ger91600TipoDeAtividadeController.deleteActivity');
  }

  public deleteActivity() {
    const grid = Metadata.getInstance<TekGrid>('tek-grid-tipo-de-atividade-grid');
    LoadingService.show();
    Http.post('/deleteActivity', {
      NRSEQTPATIVCLI: (grid.selectedRows.map((element: any) => element.NRSEQTPATIVCLI)),
    }).then(() => {
      grid.datasource.get();
      Utilities.showSuccessMessage();
    }).catch((error: any) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
